pub struct ShulkerBoxBlockEntity {
base: Arc<BlockEntityBase>,
container: Arc<SyncMutex<ShulkerBoxContainer>>,
container_ref: ContainerRef,
animation: SyncMutex<ShulkerBoxAnimation>,
open_count: AtomicI32,
}Expand description
Block entity backing every shulker box color, including the undyed one.
Fields
base: Arc<BlockEntityBase>container: Arc<SyncMutex<ShulkerBoxContainer>>container_ref: ContainerRefanimation: SyncMutex<ShulkerBoxAnimation>open_count: AtomicI32Implementations
Sourceimpl ShulkerBoxBlockEntity
impl ShulkerBoxBlockEntity
Sourcepub fn new(level: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
pub fn new(level: Weak<World>, pos: BlockPos, state: BlockStateId) -> Self
Creates a new shulker box block entity.
fn update_animation( &self, world: &Arc<World>, pos: BlockPos, state: BlockStateId, )
fn move_collided_entities( &self, world: &Arc<World>, pos: BlockPos, state: BlockStateId, )
Sourcepub fn shulker_box_as_item(&self, state: BlockStateId) -> ItemStack
pub fn shulker_box_as_item(&self, state: BlockStateId) -> ItemStack
Builds the item form of a placed, possibly-filled shulker box.
Vanilla ShulkerBoxBlockEntity.collectComponents() +
BaseContainerBlockEntity.collectImplicitComponents(CONTAINER).
Sourcepub fn get_progress_delta_aabb<I: Space>(
size: f32,
direction: Direction,
progress_from: f32,
progress_to: f32,
position: DVec3,
) -> Aabb<DVec3, I>
pub fn get_progress_delta_aabb<I: Space>( size: f32, direction: Direction, progress_from: f32, progress_to: f32, position: DVec3, ) -> Aabb<DVec3, I>
Calculates the bounding box of a shulker during its opening animation.
The bounds are expanded in the opening direction based on the animation progress.
Sourcepub fn get_bounding_box(&self, state: BlockStateId) -> BlockLocalAabb
pub fn get_bounding_box(&self, state: BlockStateId) -> BlockLocalAabb
Block-local bounds of the box including the lid at its current progress.
Sourcepub fn can_open(
&self,
state: BlockStateId,
world: &Arc<World>,
pos: BlockPos,
) -> bool
pub fn can_open( &self, state: BlockStateId, world: &Arc<World>, pos: BlockPos, ) -> bool
Returns whether the shulker box can open
Sourcepub fn collect_components(&self) -> ItemContainerContents
pub fn collect_components(&self) -> ItemContainerContents
Collect all the items inside the shulker box into an ItemContainerContents
Panics
Panics if shulker box somehow has more than 256 slots. This should never happen
Sourcepub fn progress(&self, partial_tick: f32) -> f32
pub fn progress(&self, partial_tick: f32) -> f32
Interpolated progress for smooth rendering between ticks.
Sourcepub fn animation_status(&self) -> AnimationStatus
pub fn animation_status(&self) -> AnimationStatus
Get the current animation state